Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ExpandWithFixedDoubleDollar ¶
ExpandWithFixedDoubleDollar expands the given string using os.ExpandEnv, however unlike the default behaviour of replacing a string "$$VALUE" with "VALUE", it replaces the "$$" witha single "$". This allows test authors to use the dollar symbol in their test contents (they need to escape with '$$').
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.